@@ -104,8 +104,8 @@ impl OpTrait for CommitInstantFixup {
 
                     state.close_menu();
 
-                    state.run_cmd_interactive(term, commit_fixup_cmd(&args, &rev))?;
-                    state.run_cmd_interactive(term, rebase_autosquash_cmd(&rev))
+                    state.run_cmd(term, &[], commit_fixup_cmd(&args, &rev))?;
+                    state.run_cmd(term, &[], rebase_autosquash_cmd(&rev))
                 }))
             }
             _ => None,
@@ -118,9 +118,16 @@ impl OpTrait for CommitInstantFixup {
 
 fn rebase_autosquash_cmd(rev: &OsStr) -> Command {
     let mut cmd = Command::new("git");
-    cmd.args(["rebase", "--autosquash"]);
+    cmd.args([
+        "rebase",
+        "-i",
+        "-q",
+        "--autostash",
+        "--keep-empty",
+        "--autosquash",
+    ]);
     cmd.arg(&parent(rev));
-
+    cmd.env("GIT_SEQUENCE_EDITOR", ":");
     cmd
 }
 
